@@ -2,8 +2,11 @@ test_that("Reading through directory is deprecated", {
   test_path <- vcr::vcr_test_path("fixtures")
 
   lifecycle::expect_deprecated(
-    x <- read_ipums_ddi(test_path, file_select = 1),
-    "Reading files through a directory"
+    lifecycle::expect_deprecated(
+      x <- read_ipums_ddi(test_path, file_select = 1),
+      "Reading files through a directory"
+    ),
+    "`file_select` argument"
   )
 
   # Confirm that we can still read using `file_select` for now
@@ -12,7 +15,8 @@ test_that("Reading through directory is deprecated", {
     suppressWarnings(
       read_nhgis(
         vcr::vcr_test_path("fixtures", "nhgis_unzipped"),
-        file_select = 1
+        file_select = 1,
+        verbose = FALSE
       )
     ),
     "tbl_df"
@@ -24,7 +28,7 @@ test_that("Reading through directory is deprecated", {
     "Multiple files found"
   )
   expect_error(
-    suppressWarnings(read_nhgis(test_path)),
+    suppressWarnings(read_nhgis(test_path, verbose = FALSE)),
     "No .csv or .dat files found"
   )
 
@@ -48,7 +52,9 @@ test_that("Get correct file path when loading from directory", {
   test_path <- vcr::vcr_test_path("fixtures")
 
   lifecycle::expect_deprecated(
-    x <- read_ipums_ddi(test_path, file_select = 1)
+    lifecycle::expect_deprecated(
+      x <- read_ipums_ddi(test_path, file_select = 1)
+    )
   )
 
   expect_equal(x$file_path, test_path)
