@@ -3,8 +3,10 @@ test_that("normal ddi doesn't error", {
   skip_if_not_installed("shiny")
   skip_if_not_installed("DT")
   ddi <- read_ipums_ddi(ipums_example("cps_00157.xml"))
-  ipums_view(ddi, launch = FALSE)
-  expect_true(TRUE)
+  expect_warning(
+    html_file <- ipums_view(ddi, launch = FALSE)
+  )
+  expect_true(grepl(".html$", html_file))
 })
 
 test_that("empty ddi doesn't error", {
@@ -12,8 +14,10 @@ test_that("empty ddi doesn't error", {
   skip_if_not_installed("shiny")
   skip_if_not_installed("DT")
   ddi <- new_ipums_ddi()
-  ipums_view(ddi, launch = FALSE)
-  expect_true(TRUE)
+  expect_warning(
+    html_file <- ipums_view(ddi, launch = FALSE)
+  )
+  expect_true(grepl(".html$", html_file))
 })
 
 test_that("normal microdata doesn't error", {
@@ -21,8 +25,10 @@ test_that("normal microdata doesn't error", {
   skip_if_not_installed("shiny")
   skip_if_not_installed("DT")
   data <- read_ipums_micro(ipums_example("cps_00157.xml"), verbose = FALSE)
-  ipums_view(data, launch = FALSE)
-  expect_true(TRUE)
+  expect_warning(
+    html_file <- ipums_view(data, launch = FALSE)
+  )
+  expect_true(grepl(".html$", html_file))
 })
 
 test_that("attribute-less microdata doesn't error", {
@@ -33,8 +39,10 @@ test_that("attribute-less microdata doesn't error", {
     ipums_example("cps_00157.xml"),
     verbose = FALSE, var_attrs = NULL
   )
-  ipums_view(data, launch = FALSE)
-  expect_true(TRUE)
+  expect_warning(
+    html_file <- ipums_view(data, launch = FALSE)
+  )
+  expect_true(grepl(".html$", html_file))
 })
 
 test_that("nhgis codebook doesn't error", {
@@ -42,6 +50,8 @@ test_that("nhgis codebook doesn't error", {
   skip_if_not_installed("shiny")
   skip_if_not_installed("DT")
   cb <- read_nhgis_codebook(ipums_example("nhgis0972_csv.zip"))
-  ipums_view(cb, launch = FALSE)
-  expect_true(TRUE)
+  expect_warning(
+    html_file <- ipums_view(cb, launch = FALSE)
+  )
+  expect_true(grepl(".html$", html_file))
 })
